@@ -25,9 +25,11 @@ from typing import (
 
 from coveo_functools.casing import flexfactory
 from coveo_itertools.lookups import dict_lookup
+from coveo_styles.styles import echo
 from coveo_systools.filesystem import CannotFindRepoRoot, find_repo_root
 from coveo_systools.subprocess import check_run
 
+from coveo_stew.ci.runner_status import RunnerStatus
 from coveo_stew.environment import PythonEnvironment, PythonTool, find_python_tool
 from coveo_stew.exceptions import NotAPoetryProject, StewException
 from coveo_stew.metadata.poetry_api import PoetryAPI
@@ -40,6 +42,10 @@ ENVIRONMENT_PATH_PATTERN: Final[Pattern] = re.compile(
 )
 
 
+# temporary until 1.2.0 has been cleared as fully compatible
+_CHECKED_POETRY_VERSION: bool = False
+
+
 class EnvironmentCreationBehavior(Enum):
     Full = auto()
     NoDev = auto()
@@ -273,11 +279,17 @@ class PythonProject:
         skips: Optional[List[str]] = None,
         quick: bool = False,
         parallel: bool = True,
-    ) -> bool:
+        github: bool = False,
+    ) -> RunnerStatus:
         """Launch all continuous integration runners on the project."""
         return asyncio.run(
             self.ci.launch_continuous_integration(
-                auto_fix=auto_fix, checks=checks, skips=skips, quick=quick, parallel=parallel
+                auto_fix=auto_fix,
+                checks=checks,
+                skips=skips,
+                quick=quick,
+                parallel=parallel,
+                github=github,
             )
         )
 
@@ -350,11 +362,34 @@ class PythonProject:
 
         The `environment` param will make that environment active (e.g.: `poetry env use` called before).
         """
+        global _CHECKED_POETRY_VERSION
+
         environment_variables = os.environ.copy()
         if breakout_of_venv:
             environment_variables.pop("VIRTUAL_ENV", None)
 
         with self._activate_poetry_environment(environment):
+
+            # issue a warning once when running from a non-compatible poetry version
+            if not _CHECKED_POETRY_VERSION:
+                _CHECKED_POETRY_VERSION = True
+                output = check_run(
+                    *find_python_tool(PythonTool.Poetry, environment=environment),
+                    "--version",
+                    "-vv" if self.verbose else "",
+                    working_directory=self.project_path,
+                    capture_output=True,
+                    verbose=self.verbose,
+                    env=environment_variables,
+                )
+
+                if "version 1.2" in output.casefold():
+                    echo.warning(
+                        f"{output.strip()} is not officially supported (yet)."
+                        f" Poetry `1.1.15` is the latest known compatible version."
+                        " See https://github.com/coveo/stew/readme.md for more information."
+                    )
+
             return check_run(
                 *find_python_tool(PythonTool.Poetry, environment=environment),
                 *commands,
